# -*- coding:utf-8 -*-
"""
对不同平台提供原生快速删除方法

例：
>>>import os
>>>from cgai_io.Delete import delfile,deldir,delall
>>>
>>># #删除文件
>>># path = r'\\192.168.1.248\3d\temp\a\cmd_mac.py'
>>># delfile(path)
>>>
>>>
>>># #删除文件夹
>>># path = r'D:\BaiduNetdiskDownload\AA'
>>># deldir(path,keep_dir=True)
>>>
>>>
>>>#无论文件或文件夹都直接删除
>>># path = r'D:\BaiduNetdiskDownload\ktk_103024'
>>># delall(path)
>>>


"""

from ._util import *


def delfile(file_path):
    """
    删除文件
    :param file_path: 文件路径
    :return:
    """
    if iswin():
        if isfile(file_path):
            os.popen('"del /f /s /q "%s"' % (file_path.replace('/','\\')))
        else:
            print("删除对象非文件")
    else:
        if file_path not in ['/','/*']:
            if isfile(file_path):
                os.popen("rm -rf %s" % (file_path.replace('\\', '/')))
            else:
                print("删除对象非文件")

def deldir(dir_path,keep_dir=False):
    """
    删除文件目录
    :param dir_path: 文件目录路径
    :param keep_dir: 保持源目录结构
    :return:
    """
    if iswin():
        if isdir(dir_path):
            if keep_dir:
                os.popen('"del /f /s /q "%s"' % (dir_path.replace('/', '\\')))
            else:
                os.popen('"rd  /s /q "%s"' % (dir_path.replace('/', '\\')))
        else:
            print("删除对象非文件目录")
    else:
        if isdir(dir_path):
            if dir_path not in ['/','/*']:  #禁止删全家
                if keep_dir:
                    os.popen('"find path -type f -exec rm {} \;"'.format(dir_path.replace('\\', '/')))
                else:
                    os.popen("rm -rf %s" % (dir_path.replace('\\', '/')))
        else:
            print("删除对象非文件目录")

def delall(path,keep_dir=False):
    """
    无论文件还是文件目录都删除
    :param path:
    :param keep_dir: 保持源目录结构
    :return:
    """
    if iswin():
        if keep_dir:
            os.popen('"del /f /s /q "%s"' % (path.replace('/', '\\')))
        else:
            os.popen('"rd  /s /q "%s"' % (path.replace('/', '\\')))
    else:
        if path not in ['/', '/*']:
            if keep_dir:
                os.popen('"find path -type f -exec rm {} \;"'.format(path.replace('\\', '/')))
            else:
                os.popen("rm -rf %s" % (path.replace('\\', '/')))



#-*- coding:utf-8 -*-
import os
import sys
import subprocess

def iswin():
    platform = sys.platform
    if platform == 'win32':
        return True
    else:
        return False

def isfile(_path):
    if os.path.isfile(_path):
        return True
    else:
        return False

def isdir(_path):
    if os.path.isdir(_path):
        return True
    else:
        return False


# -*- coding:utf-8 -*-
from ._util import *
import subprocess


def copyfile(src_file,des_file,auto_create=True):
    """
    复制文件
    :param src_file: 源文件路径 
    :param des_file: 复制文件路径
    :param auto_create: 自动创建目录
    :return:
    """
    if isfile(src_file):
        if auto_create:
            _dir = os.path.dirname(des_file)
            if not os.path.exists(_dir):
                os.makedirs(_dir)
        if iswin():
            src_file = src_file.replace('/', '\\')
            des_file = des_file.replace('/', '\\')
            os.popen('copy "%s" "%s"' % (src_file, des_file))
        else:
            os.popen('cp "%s" "%s"' % (src_file, des_file))
    else:
        print('复制对象非文件类型')

def copydir(src_dir,des_dir,auto_create=True):
    """
    复制文件夹
    :param src_dir: 源目录路径
    :param des_dir:  复制文件夹路径
    :param auto_create: 自动创建目录
    :return:
    """
    if isdir(src_dir):
        if auto_create:
            _dir = os.path.dirname(des_dir)
            if not os.path.exists(_dir):
                os.makedirs(_dir)
        if iswin():
            src_dir = src_dir.replace('/', '\\')
            des_dir = des_dir.replace('/', '\\')
            os.popen('xcopy "%s" "%s" /s /e /v /y /i' % (src_dir, des_dir))
        else:
            os.popen('cp -r "%s" "%s"' % (src_dir, des_dir))
    else:
        print('复制对象非目录类型')



def copyall(src,des,auto_create=True):
    """
    复制文件或文件夹
    :param src:
    :param des:
    :param auto_create: 自动创建目录
    :return:
    """
    src = src.replace('/', '\\')
    des = des.replace('/', '\\')

    if isfile(src):
        if auto_create:
            _dir = os.path.dirname(des)
            if not os.path.exists(_dir):
                os.makedirs(_dir)
        if iswin():
            os.popen('copy "%s" "%s"' % (src, des))
        else:
            os.popen('cp "%s" "%s"' % (src, des))

    if isdir(src):
        _dir = os.path.dirname(des)
        if not os.path.exists(_dir):
            os.makedirs(_dir)
        if iswin():
            os.popen('xcopy "%s" "%s" /s /e /v /y /i' % (src, des))
        else:
            os.popen('cp -r "%s" "%s"' % (src, des))


#-*- coding:utf-8 -*-
"""
打包压缩与解压文件或目录
"""
import os
import shutil
import zipfile



def pack(src:str,des:str):
    """
    打包文件或目录
    :param src: 源文件或目录
    :param des: zip路径
    :return:
    """

    if os.path.isfile(src):
        z = zipfile.ZipFile(des,"w")
        name = os.path.split(src)[1]
        z.write(src,name)
        z.close()
    elif os.path.isdir(src):
        des_dir = os.path.splitext(des)[0]
        shutil.make_archive(des_dir,'zip',root_dir=src)



def unpack(src:str,des_dir:str):
    """
    解压文件或目录
    :param src: zip路径
    :param des_dir: 解压目录
    :return:
    """
    z = zipfile.ZipFile(src,'r')
    z.extractall(des_dir)
    z.close()





#-*- coding:utf-8 -*-
"""
移动文件或目录
"""
from ._util import *


def mv(src:str,des:str):
    """
    移动文件或文件夹
    :param src: 源文件或目录
    :param des: 目标文件或目录
    :return:
    """
    if iswin():
        os.popen('move {} {}'.format(src,des))
    else:
        os.popen('mv {} {}'.format(src, des))


def mvfile(src:str,des:str):
    """
    移动文件
    :param src: 源文件
    :param des: 目标文件
    :return: 
    """
    if isfile(src):
        mv(src,des)
    else:
        raise Exception("输入非文件")

def mvdir(src:str,des:str):
    """
    移动文件目录
    :param src: 源文件目录
    :param des: 目标文件目录
    :return:
    """
    if isdir(src):
        mv(src,des)
    else:
        raise Exception("输入非文件目录")






# -*- coding:utf-8 -*-
from .Copy import *
from .Delete import *
from .Move import *
from .Name import *
from .Pack import *
__title__ = 'cgai_io'
__version__ = '0.0.9'
__author__ = 'Master Zhang'
__author_email__ = '360014296@qq.com'
__license__ = 'GPLv3'
__description__ = """ 支持跨平台，支持window文件以及目录的快速复制 \n
 复制文件 copyfile,复制目录 copydir"""




#-*- coding:utf-8 -*-
"""
对文件或目录进行重命名
"""


from ._util import *
from .Move import mv





def rename(src:str,des:str):
    """
    重命名
    :param src: 源文件或目录
    :param des: 目标文件或目录
    :return:
    """
    mv(src,des)



def addPrefix(src:str,prefix:str):
    """
    添加前缀
    :param src: 源文件路径
    :param prefix: 前缀名称
    :return:
    """
    src_dir, src_name = os.path.split(src)
    new_name = prefix + src_name
    des = os.path.join(src_dir, new_name)
    mv(src, des)


def addSuffix(src: str, suffix: str):
    """
    添加尾缀
    :param src: 源文件路径
    :param prefix: 尾缀名称
    :return:
    """
    src_dir, src_name = os.path.split(src)
    name, suf = os.path.splitext(src_name)
    new_name = name + suffix + suf
    des = os.path.join(src_dir, new_name)
    mv(src, des)
